==> pshkcms-eshopcatalog-1.0.2-479533.tar: src/AdminModule/Components/Categories/CategoryForm.php <==
<?php declare(strict_types = 1);

namespace EshopCatalog\AdminModule\Components\Categories;

use Core\Components\Flashes\Flashes;
use Core\Model\Event\ComponentTemplateEvent;
use Core\Model\Event\CreateFormEvent;
use Core\Model\Event\FormSuccessEvent;
use Core\Model\Event\SetFormDataEvent;
use Core\Model\UI\BaseControl;
use Core\Model\UI\Form\BaseForm;
use Core\FrontModule\Model\SeoContainer;
use EshopCatalog\AdminModule\Components\Features\FeatureForm;
use EshopCatalog\Model\Entities\CategoryFilter;
use EshopCatalog\Model\Entities\CategoryTmp;
use EshopCatalog\Model\Entities\Feature;
use Nette\Http\IResponse;
use Nette\Utils\ArrayHash;
use EshopCatalog\Model\Entities\Category;
use EshopCatalog\Model\Entities\CategoryTexts;
use EshopCatalog\AdminModule\Model\Categories;

/**
 * Class CategoryForm
 * @package EshopCatalog\AdminModule\Components\Categories
 */
class CategoryForm extends BaseControl
{
	/** @var int @persistent */
	public $categoryId;

	/** @var Category */
	public $category;

	/** @var Categories */
	protected $categoryServices;

	/** @var SeoContainer */
	protected $seoContainerService;

	/** @var Category */
	protected $root;

	public function __construct(Categories $categories, SeoContainer $seoContainer)
	{
		$this->categoryServices    = $categories;
		$this->seoContainerService = $seoContainer;
	}

	public function render()
	{
		$this->eventDispatcher->dispatch(CategoryForm::class . '::render',
			new ComponentTemplateEvent($this->template, $this));
		$this->template->render($this->getTemplateFile());
	}

	protected function attached($presenter)
	{
		parent::attached($presenter);

		$root = $this->categoryServices->getEr()->findOneBy([
			'lvl' => 0,
		]);

		if (!$root) {
			$root              = new Category();
			$root->isPublished = 1;

			$texts = new CategoryTexts($root, $this->translator->getLocale());
			$texts->setName('ROOT');
			$root->setCategoryText($texts);

			$this->em->persist($root)->persist($texts)->flush();
		}
	}

	protected function createComponentForm()
	{
		$form = $this->createForm();
		$form->setAjax();

		$root       = $this->categoryServices->getEr()->findOneBy(['lvl' => 0, 'parent' => null]);
		$categories = [$root->getId() => ''];
		foreach ($this->em->getRepository(Category::class)->createQueryBuilder('c')
			         ->select('c.id, ct.name, c.lvl')
			         ->where('c.lvl > 0')->andWhere('ct.name != \'\'')
			         ->leftJoin('c.categoryTexts', 'ct', 'WITH', 'ct.lang = :lang')
			         ->setParameter('lang', $this->translator->getLocale())
			         ->orderBy('c.root')->addOrderBy('c.lft')
			         ->getQuery()->getResult() as $c) {
			$name = ' ' . $c['name'];
			for ($i = 1; $i < $c['lvl']; $i++)
				$name = '---' . $name;
			$categories[$c['id']] = trim($name);
		}
		$filters = [];
		foreach ($this->em->getRepository(Feature::class)->createQueryBuilder('f')->select('f.id, ft.name')
			         ->join('f.featureTexts', 'ft', 'WITH', 'ft.lang = :lang')
			         ->andWhere('f.useAsFilter = 1')
			         ->setParameters(['lang' => $this->translator->getLocale()])->orderBy('f.position')
			         ->getQuery()->getArrayResult() as $row) {
			$filters[$row['id']] = $row['name'];
		}

		$form->addText('name', 'eshopCatalog.categoryForm.name')
			->setMaxLength(255)->setNullable()
			->setIsMultilanguage();
		$form->addText('alias', 'eshopCatalog.categoryForm.alias')->setMaxLength(255)->setIsMultilanguage();
		$form->addText('nameH1', 'eshopCatalog.categoryForm.nameH1')->setMaxLength(255)->setIsMultilanguage();
		$form->addBool('isPublished', 'eshopCatalog.categoryForm.isPublished')->setDefaultValue(1);
		$form->addSelect('parent', $this->t('default.parent'), $categories)->setTranslator(null);
		$form->addFilesManager('image', 'default.image');
		$form->addEditor('desc', 'eshopCatalog.categoryForm.desc')->setHeight(300)
			->setDisableAutoP(false)
			->setIsMultilanguage();
		$form->addBool('filtersFromParent', 'eshopCatalog.categoryForm.filtersFromParent')->setDefaultValue(1);
		$form->addSortableCheckboxList('filters', $this->t('eshopCatalog.categoryForm.availableFilters'), $filters)->setTranslator(null);

		$form->addComponent($this->seoContainerService->getContainer(true), 'seo');

		$this->eventDispatcher->dispatch(CategoryForm::class . '::createForm',
			new CreateFormEvent($form, $this->getPresenter(false) ? $this->template : null));

		$form->addSaveCancelControl('saveControl');

		$form->onValidate[] = [$this, 'formValidate'];
		$form->onSuccess[]  = [$this, 'formSuccess'];

		return $form;
	}

	public function formValidate(BaseForm $form, ArrayHash $values): void
	{
		$nameFilled = false;
		foreach ($values->name as $v)
			if ($v)
				$nameFilled = true;

		if (!$nameFilled)
			$form->addError('eshopCatalog.categoryForm.categoryNameMissing');
		if ($form->hasErrors())
			$this->redrawControl('form');
	}

	public function formSuccess(BaseForm $form, ArrayHash $values): bool
	{
		try {
			$langValues = $form->convertMultilangValuesToArray();
			/** @var CategoryTexts[] $categoryTexts */
			$categoryTexts = [];

			if ($this->categoryId) {
				$this->category = $this->categoryServices->get($this->categoryId);
				$categoryTexts  = $this->category->getCategoryTexts()->toArray();
			}

			$category = $this->category ?: new Category();
			$seoData  = $this->seoContainerService->getFormData($values->seo, true);

			foreach ($langValues as $l => $v) {
				if ($v['name'] == '') {
					if (isset($categoryTexts[$l])) {
						$this->em->remove($categoryTexts[$l]);
						unset($categoryTexts[$l]);
					}
					continue;
				}

				if (!$categoryTexts[$l])
					$categoryTexts[$l] = new CategoryTexts($category, $l);

				$categoryTexts[$l]->setName($v['name'])
					->setAlias($v['alias'])
					->setNameH1($v['nameH1'])
					->setSeo($seoData[$l] ?? []);
				$categoryTexts[$l]->description = $v['desc'];

				$this->em->persist($categoryTexts[$l]);
			}

			$category->setCategoryTexts($categoryTexts);

			$category->isPublished       = $values->isPublished;
			$category->image             = $values->image;
			$category->filtersFromParent = $values->filtersFromParent;


			if ($values->parent == '') {
				$category->setParent(null);
			} else {
				$category->setParent($this->categoryServices->get($values->parent));
			}
			$this->em->persist($category);

			// FILTRY
			$formFilters     = $values->filters;
			$categoryFilters = $category->filters->toArray();

			// nové
			foreach (array_diff($formFilters, array_keys($categoryFilters)) as $k => $v) {
				$categoryFilter = new CategoryFilter($category, $this->em->getReference(Feature::class, $v), $k);
				$this->em->persist($categoryFilter);
				$category->filters->add($categoryFilter);
			}

			// odstranit
			foreach (array_diff(array_keys($categoryFilters), $formFilters) as $v) {
				$categoryFilter = $category->filters->get($v);
				if ($categoryFilter) {
					$category->filters->remove($v);
					$this->em->remove($categoryFilter);
				}
			}

			// seřadit
			foreach ($formFilters as $k => $v) {
				$categoryFilter = $category->filters->get($v);
				if ($categoryFilter) {
					$categoryFilter->position = $k;
					$this->em->persist($categoryFilter);
				}
			}

			$event                   = new FormSuccessEvent($form, $values,
				$this->getPresenter(false) ? $this->template : null, $this->getPresenter(false) ? $this->getPresenter() : null);
			$event->custom['entity'] = $category;
			$this->eventDispatcher->dispatch(CategoryForm::class . '::formSuccess', $event);

			$this->em->flush();
			$form->addCustomData('categoryId', $category->getId());
			$this->getPresenter()->flashMessageSuccess('eshopCatalog.categoryForm.categorySaved', Flashes::FLASH_SUCCESS);
		} catch (\Exception $e) {
			$form->addError($e->getMessage());
			bdump($e);
			$this->redrawControl('form');

			return false;
		}

		return true;
	}

	public function setCategory($id)
	{
		$this->categoryId = $id;
		$this->category   = $this->categoryServices->get($id);

		if ($this->category) {
			$c    = $this->category;
			$form = $this['form'];

			$defaults = ([
				'isPublished'       => $c->isPublished,
				'image'             => $c->image,
				'filtersFromParent' => $c->filtersFromParent,
			]);
			if (isset($c->parent) && array_key_exists($c->parent->getId(), $form['parent']->getItems()))
				$defaults['parent'] = $c->parent->getId();

			$form->setDefaults($defaults);

			// Texty
			$mTexts  = [];
			$seoData = [];
			foreach ($c->getCategoryTexts()->toArray() as $lang => $texts) {
				foreach (['name', 'alias', 'description' => 'desc', 'nameH1'] as $k => $v) {
					$k = is_string($k) ? $k : $v;

					$mTexts[$v][$lang] = $texts->$k;
				}

				foreach ($texts->getSeo() as $k => $v)
					$seoData[$k][$lang] = $v;
			}
			$form->setDefaults($mTexts);
			$this->seoContainerService->setDefaults($form['seo'], $seoData);

			// Filtry
			$defaults = [];
			foreach ($c->filters->toArray() as $k => $v) {
				if (array_key_exists($k, $form['filters']->getItems()))
					$defaults[] = $k;
			}
			$form['filters']->setDefaultValue($defaults);
			$this->eventDispatcher->dispatch(CategoryForm::class . '::setFeature', new SetFormDataEvent($form, $this->category));
		} else
			$this->getPresenter()->error(null, IResponse::S404_NOT_FOUND);
	}
}

==> pshkcms-eshopcatalog-1.0.16-616757.tar: src/AdminModule/Components/Categories/CategoryForm.php <==
<?php declare(strict_types = 1);

namespace EshopCatalog\AdminModule\Components\Categories;

use Core\Components\Flashes\Flashes;
use Core\Model\Event\ComponentTemplateEvent;
use Core\Model\Event\CreateFormEvent;
use Core\Model\Event\FormSuccessEvent;
use Core\Model\Event\FormValidateEvent;
use Core\Model\Event\SetFormDataEvent;
use Core\Model\UI\BaseControl;
use Core\Model\UI\Form\BaseContainer;
use Core\Model\UI\Form\BaseForm;
use Core\FrontModule\Model\SeoContainer;
use EshopCatalog\AdminModule\Components\Products\ProductForm;
use EshopCatalog\Model\Entities\CategoryFilter;
use EshopCatalog\Model\Entities\CategoryExport;
use EshopCatalog\Model\Entities\Feature;
use EshopCatalog\Model\Helpers\ExportEnums;
use Nette\Http\IResponse;
use Nette\Utils\ArrayHash;
use EshopCatalog\Model\Entities\Category;
use EshopCatalog\Model\Entities\CategoryTexts;
use EshopCatalog\AdminModule\Model\Categories;

/**
 * Class CategoryForm
 * @package EshopCatalog\AdminModule\Components\Categories
 */
class CategoryForm extends BaseControl
{
	/** @var int @persistent */
	public $categoryId;

	/** @var Category */
	public $category;

	/** @var Categories */
	protected $categoryServices;

	/** @var SeoContainer */
	protected $seoContainerService;

	/** @var Category */
	protected $root;

	public function __construct(Categories $categories, SeoContainer $seoContainer)
	{
		$this->categoryServices    = $categories;
		$this->seoContainerService = $seoContainer;
	}

	public function render()
	{
		$this->eventDispatcher->dispatch(CategoryForm::class . '::render',
			new ComponentTemplateEvent($this->template, $this));
		$this->template->render($this->getTemplateFile());
	}

	protected function attached($presenter)
	{
		parent::attached($presenter);

		$root = $this->categoryServices->getEr()->findOneBy([
			'lvl' => 0,
		]);

		if (!$root) {
			$root              = new Category();
			$root->isPublished = 1;

			$texts = new CategoryTexts($root, $this->translator->getLocale());
			$texts->setName('ROOT');
			$root->setCategoryText($texts);

			$this->em->persist($root)->persist($texts)->flush();
		}
	}

	protected function createComponentForm()
	{
		$form = $this->createForm();
		$form->setAjax();

		$root       = $this->categoryServices->getEr()->findOneBy(['lvl' => 0, 'parent' => null]);
		$categories = [$root->getId() => ''];
		foreach ($this->em->getRepository(Category::class)->createQueryBuilder('c')
			         ->select('c.id, ct.name, c.lvl')
			         ->where('c.lvl > 0')->andWhere('ct.name != \'\'')
			         ->leftJoin('c.categoryTexts', 'ct', 'WITH', 'ct.lang = :lang')
			         ->setParameter('lang', $this->translator->getLocale())
			         ->orderBy('c.root')->addOrderBy('c.lft')
			         ->getQuery()->getResult() as $c) {
			$name = ' ' . $c['name'];
			for ($i = 1; $i < $c['lvl']; $i++)
				$name = '---' . $name;
			$categories[$c['id']] = trim($name);
		}
		$filters = [];
		foreach ($this->em->getRepository(Feature::class)->createQueryBuilder('f')->select('f.id, ft.name')
			         ->join('f.featureTexts', 'ft', 'WITH', 'ft.lang = :lang')
			         ->andWhere('f.useAsFilter = 1')
			         ->setParameters(['lang' => $this->translator->getLocale()])->orderBy('f.position')
			         ->getQuery()->getArrayResult() as $row) {
			$filters[$row['id']] = $row['name'];
		}

		$form->addText('name', 'eshopCatalog.categoryForm.name')
			->setMaxLength(255)->setNullable()
			->setIsMultilanguage();
		$form->addText('alias', 'eshopCatalog.categoryForm.alias')->setMaxLength(255)->setIsMultilanguage();
		$form->addText('nameH1', 'eshopCatalog.categoryForm.nameH1')->setMaxLength(255)->setIsMultilanguage();
		$form->addBool('canProductsAddToCart', 'eshopCatalog.categoryForm.canProductsAddToCart')->setDefaultValue(1);
		$form->addBool('isPublished', 'eshopCatalog.categoryForm.isPublished')->setDefaultValue(1);
		$form->addSelect('parent', $this->t('default.parent'), $categories)->setTranslator(null);
		$form->addFilesManager('image', 'default.image');
		$form->addEditor('descShort', 'eshopCatalog.categoryForm.descShort')->setHeight(200)
			->setDisableAutoP(false)
			->setIsMultilanguage();
		$form->addEditor('desc', 'eshopCatalog.categoryForm.desc')->setHeight(300)
			->setDisableAutoP(false)
			->setIsMultilanguage();
		$form->addBool('filtersFromParent', 'eshopCatalog.categoryForm.filtersFromParent')->setDefaultValue(1);
		$form->addSortableCheckboxList('filters', $this->t('eshopCatalog.categoryForm.availableFilters'), $filters)->setTranslator(null);

		$form->addComponent($this->seoContainerService->getContainer(true), 'seo');

		//Porovnávače
		foreach (ExportEnums::$services as $k => $v) {
			$container = new BaseContainer();
			$container->addBool('status', 'eshopCatalog.porovnavace.status', [
				0 => ['title' => 'default.no', 'btnClass' => 'danger'],
				1 => ['title' => 'default.yes', 'btnClass' => 'success'],
				2 => ['title' => 'eshopCatalog.categoryForm.fromParent', 'btnClass' => 'secondary'],
			])
				->setDefaultValue(2);
			$container->addHidden('categoryId');
			$container->addText('categoryText', 'eshopCatalog.porovnavace.' . $k . '.categoryText')
				->setHtmlAttribute('data-grader-type', $k)
				->setHtmlAttribute('data-grader-id', 'p_' . $k . '[' . $container['categoryId']->getName() . ']')
				->setMaxLength(255);

			$form->addComponent($container, 'p_' . $k);
		}

		$this->eventDispatcher->dispatch(CategoryForm::class . '::createForm',
			new CreateFormEvent($form, $this->getPresenter(false) ? $this->template : null));

		$form->addSaveCancelControl('saveControl');

		$form->onValidate[] = [$this, 'formValidate'];
		$form->onSuccess[]  = [$this, 'formSuccess'];

		return $form;
	}

	public function formValidate(BaseForm $form, ArrayHash $values): void
	{
		$presenter  = $this->getPresenter();
		$nameFilled = false;
		foreach ($values->name as $v)
			if ($v)
				$nameFilled = true;

		if (!$nameFilled)
			$form->addError('eshopCatalog.categoryForm.categoryNameMissing');

		$this->eventDispatcher->dispatch(ProductForm::class . '::validateForm',
			new FormValidateEvent($form, $values, $presenter ? $this->template : null, $presenter ?: null));

		if ($form->hasErrors())
			$this->redrawControl('form');
	}

	public function formSuccess(BaseForm $form, ArrayHash $values): bool
	{
		try {
			$langValues = $form->convertMultilangValuesToArray();
			/** @var CategoryTexts[] $categoryTexts */
			$categoryTexts = [];

			if ($this->categoryId) {
				$this->category = $this->categoryServices->get($this->categoryId);
				$categoryTexts  = $this->category->getCategoryTexts()->toArray();
			}

			$category = $this->category ?: new Category();
			$seoData  = $this->seoContainerService->getFormData($values->seo, true);

			foreach ($langValues as $l => $v) {
				if ($v['name'] == '') {
					if (isset($categoryTexts[$l])) {
						$this->em->remove($categoryTexts[$l]);
						unset($categoryTexts[$l]);
					}
					continue;
				}

				if (!$categoryTexts[$l])
					$categoryTexts[$l] = new CategoryTexts($category, $l);

				$categoryTexts[$l]->setName($v['name'])
					->setAlias($v['alias'])
					->setNameH1($v['nameH1'])
					->setSeo($seoData[$l] ?? []);
				$categoryTexts[$l]->description      = $v['desc'];
				$categoryTexts[$l]->shortDescription = $v['descShort'];

				$this->em->persist($categoryTexts[$l]);
			}

			$category->setCategoryTexts($categoryTexts);

			$category->isPublished          = $values->isPublished;
			$category->image                = $values->image;
			$category->filtersFromParent    = $values->filtersFromParent;
			$category->canProductsAddToCart = $values->canProductsAddToCart;


			if ($values->parent == '') {
				$category->setParent(null);
			} else {
				$category->setParent($this->categoryServices->get($values->parent));
			}
			$this->em->persist($category);

			// FILTRY
			$formFilters     = $values->filters;
			$categoryFilters = $category->filters->toArray();

			// nové
			foreach (array_diff($formFilters, array_keys($categoryFilters)) as $k => $v) {
				$categoryFilter = new CategoryFilter($category, $this->em->getReference(Feature::class, $v), $k);
				$this->em->persist($categoryFilter);
				$category->filters->add($categoryFilter);
			}

			// odstranit
			foreach (array_diff(array_keys($categoryFilters), $formFilters) as $v) {
				$categoryFilter = $category->filters->get($v);
				if ($categoryFilter) {
					$category->filters->remove($v);
					$this->em->remove($categoryFilter);
				}
			}

			// seřadit
			foreach ($formFilters as $k => $v) {
				$categoryFilter = $category->filters->get($v);
				if ($categoryFilter) {
					$categoryFilter->position = $k;
					$this->em->persist($categoryFilter);
				}
			}

			$this->em->flush();

			// Porovnávače
			$exports    = [];
			$exportVals = [];
			foreach ($this->em->getRepository(CategoryExport::class)->createQueryBuilder('cpe')
				         ->where('cpe.id = :id')->setParameter('id', $category->getId())
				         ->getQuery()->getResult() as $row)
				$exports[$row->service][$row->lang] = $row;

			foreach (ExportEnums::$services as $serviceName => $v) {
				$exportVals[$serviceName] = $values['p_' . $serviceName];
			}

			foreach ($exportVals as $serviceName => $vals) {
				$lang = 'cs';

				if (isset($exports[$serviceName][$lang]))
					$export = $exports[$serviceName][$lang];
				else
					$export = new CategoryExport($category, $lang, $serviceName);

				$val = $vals['categoryId'];
				if (!$val)
					$val = $vals['categoryText'];

				$export->status       = $vals['status'];
				$export->categoryText = $val ?: null;

				$this->em->persist($export);
			}

			$event                   = new FormSuccessEvent($form, $values,
				$this->getPresenter(false) ? $this->template : null, $this->getPresenter(false) ? $this->getPresenter() : null);
			$event->custom['entity'] = $category;
			$this->eventDispatcher->dispatch(CategoryForm::class . '::formSuccess', $event);

			$this->em->flush();
			$form->addCustomData('categoryId', $category->getId());
			$this->getPresenter()->flashMessageSuccess('eshopCatalog.categoryForm.categorySaved', Flashes::FLASH_SUCCESS);
		} catch (\Exception $e) {
			$form->addError($e->getMessage());
			bdump($e);
			$this->redrawControl('form');

			return false;
		}

		return true;
	}

	public function setCategory($id)
	{
		$this->categoryId = $id;
		$this->category   = $this->categoryServices->get($id);

		if ($this->category) {
			$c    = $this->category;
			$form = $this['form'];

			$defaults = ([
				'isPublished'          => $c->isPublished,
				'image'                => $c->image,
				'filtersFromParent'    => $c->filtersFromParent,
				'canProductsAddToCart' => $c->canProductsAddToCart,
			]);
			if (isset($c->parent) && array_key_exists($c->parent->getId(), $form['parent']->getItems()))
				$defaults['parent'] = $c->parent->getId();

			$form->setDefaults($defaults);

			// Texty
			$mTexts  = [];
			$seoData = [];
			foreach ($c->getCategoryTexts()->toArray() as $lang => $texts) {
				foreach (['name', 'alias', 'description' => 'desc', 'shortDescription' => 'descShort',
					         'nameH1'] as $k => $v) {
					$k = is_string($k) ? $k : $v;

					$mTexts[$v][$lang] = $texts->$k;
				}

				foreach ($texts->getSeo() as $k => $v)
					$seoData[$k][$lang] = $v;
			}
			$form->setDefaults($mTexts);
			$this->seoContainerService->setDefaults($form['seo'], $seoData);

			// Filtry
			$defaults = [];
			foreach ($c->filters->toArray() as $k => $v) {
				if (array_key_exists($k, $form['filters']->getItems()))
					$defaults[] = $k;
			}
			$form['filters']->setDefaultValue($defaults);

			// Porovnávače
			$exports = [];
			foreach ($this->em->getRepository(CategoryExport::class)->createQueryBuilder('cpe')
				         ->where('cpe.id = :id')->setParameter('id', $c->getId())
				         ->getQuery()->getArrayResult() as $row) {
				foreach ($row as $k => $v) {
					if (in_array($k, ['service', 'lang', 'id']))
						continue;
					$exports['p_' . $row['service']][$k] = $v;
				}

				if (is_numeric($exports['p_' . $row['service']]['categoryText']))
					$exports['p_' . $row['service']]['categoryId'] = $exports['p_' . $row['service']]['categoryText'];
			}
			$form->setDefaults($exports);

			$this->eventDispatcher->dispatch(CategoryForm::class . '::setCategory', new SetFormDataEvent($form, $this->category));
		} else
			$this->getPresenter()->error(null, IResponse::S404_NOT_FOUND);
	}
}
